.. role:: hidden
    :class: hidden-section

ax.models
===================================

.. automodule:: ax.models
.. currentmodule:: ax.models


Base Models & Utilities
-----------------------

ax.models.base
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.base
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.discrete\_base module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.discrete_base
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch\_base module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch_base
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.model\_utils module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.model_utils
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.types
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.types
    :members:
    :undoc-members:
    :show-inheritance:


Discrete Models
----------------

ax.models.discrete.eb\_thompson module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.discrete.eb_thompson
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.discrete.full\_factorial module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.discrete.full_factorial
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.discrete.thompson module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.discrete.thompson
    :members:
    :undoc-members:
    :show-inheritance:



Random Models
----------------

ax.models.random.base module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.random.base
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.random.uniform module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.random.uniform
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.random.sobol module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.random.sobol
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.random.alebo_initializer module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.random.alebo_initializer
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.random.rembo_initializer module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.random.rembo_initializer
    :members:
    :undoc-members:
    :show-inheritance:


Torch Models & Utilities
------------------------

ax.models.torch.alebo module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.alebo
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.botorch module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.botorch
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.botorch_defaults module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.botorch_defaults
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.botorch_kg module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.botorch_kg
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.botorch_mes module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.botorch_mes
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.botorch_moo module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.botorch_moo
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.botorch_moo_defaults module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.botorch_moo_defaults
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.botorch_modular.acquisition module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.botorch_modular.acquisition
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.botorch_modular.default_options module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.botorch_modular.default_options
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.botorch_modular.list_surrogate module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.botorch_modular.list_surrogate
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.randomforest module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.randomforest
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.botorch_modular.model module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.botorch_modular.model
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.botorch_modular.multi_fidelity module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.botorch_modular.multi_fidelity
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.botorch_modular.optimizer_argparse module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.botorch_modular.optimizer_argparse
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.botorch_modular.surrogate module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.botorch_modular.surrogate
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.botorch_modular.utils module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.botorch_modular.utils
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.cbo_lcea module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.cbo_lcea
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.cbo_lcem module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.cbo_lcem
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.cbo_sac module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.cbo_sac
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.frontier_utils module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.frontier_utils
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.fully_bayesian module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.fully_bayesian
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.fully_bayesian_model_utils module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.fully_bayesian_model_utils
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.posterior_mean module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.posterior_mean
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.rembo module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.rembo
    :members:
    :undoc-members:
    :show-inheritance:

ax.models.torch.utils module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.models.torch.utils
    :members:
    :undoc-members:
    :show-inheritance:
